<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Gruppide seadistused</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Grupi nimi:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Lase süsteemil valida</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Grupi ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Kasutajad, kes kuuluvad siia gruppi:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Grupil peab olema nimi.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Kasutajate ja kasutajagruppide seadistused</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Kasutajad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Kasutajanimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Kasutaja ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Täielik nimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Grupp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Kodukaust</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Näita süsteemseid kasutajaid (süsteemihaldurile vajalik teave)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Grupid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Grupi ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Liikmed</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Edit properties of the selected item</source>
        <translation>Muuda valitud kirje omadusi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Lisa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Lisa uusi kasutajaid või kasutajagruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Kustuta valitud kirje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Omadused</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Värskenda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Värskenda loendid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Muuda salasõna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Muuda valitud kasutaja või grupi salasõna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Kas sa oled kindel, et soovid selle kasutaja kustutada?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Kas sa oled kindel, et soovid selle grupi kustutada?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="202"/>
        <source>Input the new password for %1:</source>
        <translation>Sisesta %1 uus salasõna:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Kas sa oled kindel, et soovid sisestada olematut salasõna?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Kasutaja seadistused</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Üldandmed</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Täisnimi:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Kasutajanimi:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Kasutaja ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Vaikimisi väärtus</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Põhiline kasutajagrupp:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Grupid</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>Kasutaja on järgnevate gruppide liige:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Lisaseadistused</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Kest sisselogimiseks:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Kodukaust:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>Kasutajanime väärtus ei tohi olla tühi.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="229"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Toiming (%1) ei õnnestunud:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
